@@ -11,6 +11,7 @@ namespace PHPUnit\TestFixture\TestRunnerStopping;
 
 use const E_USER_DEPRECATED;
 use function trigger_error;
+use PHPUnit\Event\Facade as EventFacade;
 use PHPUnit\Framework\TestCase;
 
 final class DeprecationTest extends TestCase
@@ -26,4 +27,14 @@ final class DeprecationTest extends TestCase
     {
         $this->assertTrue(true);
     }
+
+    public function testThree(): void
+    {
+        $this->assertTrue(true);
+
+        EventFacade::emitter()->testTriggeredPhpunitDeprecation(
+            $this->valueObjectForEvents(),
+            'message',
+        );
+    }
 }
