@@ -25,9 +25,8 @@ final class TestTest extends TestCase
         return [
             [true, new ReflectionMethod(TestCaseTest::class, 'testOne')],
             [true, new ReflectionMethod(TestCaseTest::class, 'two')],
-            [true, new ReflectionMethod(TestCaseTest::class, 'three')],
+            [false, new ReflectionMethod(TestCaseTest::class, 'three')],
             [false, new ReflectionMethod(TestCaseTest::class, 'four')],
-            [false, new ReflectionMethod(TestCaseTest::class, 'five')],
         ];
     }
 
